[kupfer] Change 'Gnome' -> 'GNOME' everywhere and fix other typos



commit 896ea0f30648ccc71c9c9405a14b7dd22abaf49a
Author: Francesco Marella <francesco marella gmail com>
Date:   Thu Mar 18 01:30:02 2010 +0100

    Change 'Gnome' -> 'GNOME' everywhere and fix other typos

 Documentation/Manual.rst        |    4 ++--
 help/Makefile.am                |    2 +-
 kupfer/obj/objects.py           |    4 ++--
 kupfer/plugin/gnome_terminal.py |   12 ++++++------
 kupfer/plugin/session_gnome.py  |    6 +++---
 5 files changed, 14 insertions(+), 14 deletions(-)
---
diff --git a/Documentation/Manual.rst b/Documentation/Manual.rst
index b76d989..fefada8 100644
--- a/Documentation/Manual.rst
+++ b/Documentation/Manual.rst
@@ -287,7 +287,7 @@ kupfer is translated using gettext and it is managed in the build system
 using ``intltool``. Translation messages are located in the ``po/``
 directory.
 
-Kupfer's localizations are listed among Gnome's modules. Its homepage
+Kupfer's localizations are listed among GNOME's modules. Its homepage
 is:
 
     http://l10n.gnome.org/module/kupfer/
@@ -344,7 +344,7 @@ Go into the directory ``po``
 
    + Write in yourself as author
    + Check ``plurals`` (copy from a language that you know uses the same
-     number of plural forms, or look up in Gnome's translation pages.)
+     number of plural forms, or look up in GNOME's translation pages.)
    + Replace everything written in CAPS
 
 Fill in the charset used; Kupfer translations *must* use the UTF-8 encoding.
diff --git a/help/Makefile.am b/help/Makefile.am
index a49ab43..36b9cb2 100644
--- a/help/Makefile.am
+++ b/help/Makefile.am
@@ -2,7 +2,7 @@
 # This file defines variables and files for Kupfer's
 # mallard documentation.
 #
-# This file is needed for Gnome's translation infrastructure,
+# This file is needed for GNOME's translation infrastructure,
 # but it is never used as a real Makefile.
 #
 # Define all languages for translation in the variable DOC_LINGUAS
diff --git a/kupfer/plugin/gnome_terminal.py b/kupfer/plugin/gnome_terminal.py
index c7a4c7e..230758b 100644
--- a/kupfer/plugin/gnome_terminal.py
+++ b/kupfer/plugin/gnome_terminal.py
@@ -1,6 +1,6 @@
-__kupfer_name__ = _("Gnome Terminal Profiles")
+__kupfer_name__ = _("GNOME Terminal Profiles")
 __kupfer_sources__ = ("SessionsSource", )
-__description__ = _("Launch Gnome Terminal profiles")
+__description__ = _("Launch GNOME Terminal profiles")
 __version__ = ""
 __author__ = "Chmouel Boudjnah <chmouel chmouel com>"
 
@@ -18,7 +18,7 @@ GCONF_KEY = "/apps/gnome-terminal/profiles"
 
 
 class Terminal(Leaf):
-	""" Leaf represent profile saved in Gnome Terminal"""
+	""" Leaf represent profile saved in GNOME Terminal"""
 
 	def __init__(self, name):
 		Leaf.__init__(self, name, name)
@@ -31,7 +31,7 @@ class Terminal(Leaf):
 
 
 class OpenSession(Action):
-	""" Opens Gnome Terminal profile """
+	""" Opens GNOME Terminal profile """
 	def __init__(self):
 		Action.__init__(self, _("Open"))
 
@@ -45,11 +45,11 @@ class OpenSession(Action):
 
 
 class SessionsSource(ApplicationSource):
-	""" Yield Gnome Terminal profiles """
+	""" Yield GNOME Terminal profiles """
 	appleaf_content_id = 'gnome-terminal'
 
 	def __init__(self):
-		ApplicationSource.__init__(self, name=_("Gnome Terminal Profiles"))
+		ApplicationSource.__init__(self, name=_("GNOME Terminal Profiles"))
 
 	def get_items(self):
 		gc = gconf.client_get_default()
diff --git a/kupfer/plugin/session_gnome.py b/kupfer/plugin/session_gnome.py
index 5a37ec8..7deb752 100644
--- a/kupfer/plugin/session_gnome.py
+++ b/kupfer/plugin/session_gnome.py
@@ -1,6 +1,6 @@
-__kupfer_name__ = _("Gnome Session Management")
+__kupfer_name__ = _("GNOME Session Management")
 __kupfer_sources__ = ("GnomeItemsSource", )
-__description__ = _("Special items and actions for Gnome environment")
+__description__ = _("Special items and actions for GNOME environment")
 __version__ = "2009-12-05"
 __author__ = "Ulrik Sverdrup <ulrik sverdrup gmail com>"
 
@@ -14,7 +14,7 @@ LOCKSCREEN_CMD = ("gnome-screensaver-command --lock", "xdg-screensaver lock")
 
 class GnomeItemsSource (support.CommonSource):
 	def __init__(self):
-		support.CommonSource.__init__(self, _("Gnome Session Management"))
+		support.CommonSource.__init__(self, _("GNOME Session Management"))
 	def get_items(self):
 		return (
 			support.Logout(LOGOUT_CMD),



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/kupfer/obj/objects.py b/kupfer/obj/objects.py
index 36d5ee5..4682c8e 100644
--- a/kupfer/obj/objects.py
+++ b/kupfer/obj/objects.py
@@ -312,7 +312,7 @@ class LaunchAgain (Launch):
 		return _("Launch another instance of this application")
 
 class CloseAll (Action):
 	"""Attept to close all application windows"""
 	rank_adjust = -10
 	def __init__(self):
 		Action.__init__(self, _("Close"))
@@ -323,7 +323,7 @@ class CloseAll (Action):
 	def valid_for_item(self, leaf):
 		return launch.application_is_running(leaf.object)
 	def get_description(self):
-		return _("Attept to close all application windows")
+		return _("Attempt to close all application windows")
 	def get_icon_name(self):
 		return "gtk-close"
 
@@ -312,7 +312,7 @@ class LaunchAgain (Launch):
 
 class CloseAll (Action):
-	"""Attept to close all application windows"""
+	"""Attempt to close all application windows"""
 	rank_adjust = -10
 	def __init__(self):